<?xml version="1.0" encoding="UTF-8"?>
<#-- Import common macros and functions -->
<#import "macros_common_general.ftl" as com>
<#include "spc_utils.ftl">
<#import "spc_utils.ftl" as spcUtils>
<#import "common_module_classification_and_labelling.ftl" as keyClassifcationAndLabellingInformation>

<@com.initializeMainVariables/>
<@com.initiateRelevanceSPC relevance/>

<#if spcFamilyContext?has_content>
    <#assign data = spcFamilyContext?eval_json />

    <#if data.spcProductPublicationInputs?has_content>
        <#global productAuthorizationNumbersMap = convertArrayToMap(data.spcProductPublicationInputs, "productDocName", "authorizationNumber")/>
    </#if>

    <#if data.metaSpcPublicationInput?has_content>
        <#global metaSPCsuficesMap = convertArrayToMap(data.metaSpcPublicationInput, "metaSpcDocName", "metaSpcSuffix")/>
    </#if>

    <#if data.authorisationNumber?has_content>
        <#global externalAuthorisationNumber = data.authorisationNumber/>
    </#if>

    <#if data.authorisationHolderName?has_content>
        <#global externalAuthorisationName = data.authorisationHolderName/>
    </#if>

    <#if data.authorisationHolderAddress?has_content>
        <#global externalAuthorisationAddressStreet = data.authorisationHolderAddress.street/>
        <#global externalAuthorisationAddressPostalCode = data.authorisationHolderAddress.postalCode/>
        <#global externalAuthorisationAddressCity = data.authorisationHolderAddress.city/>
        <#global externalAuthorisationAddressCountry = data.authorisationHolderAddress.country.code/>
    </#if>

    <#if data.validityStartDateStandardPhrase?has_content>
        <#global externalAuthorisationStartDate = data.validityStartDateStandardPhrase/>
    </#if>

    <#if data.validityEndDateStandardPhrase?has_content>
        <#global externalAuthorisationEndDate = data.validityEndDateStandardPhrase/>
    </#if>

</#if>

<#-- get dossier header variable to reuse -->
<#assign dossier = _dossierHeader />

<#-------------------------------------------------------------------
---------------------------------------------------------------------
assign the language code as selected in dossier header, and 
base the hardcoded language output on this.
The *global *languageLocale in spc_utils is used to get the language 
---------------------------------------------------------------------
-------------------------------------------------------------------->
<#if dossier.submissionType?matches(".*SPC.*") && dossier.SpecificSubmissions.Language?has_content>
    <#assign firstLanguage = dossier.SpecificSubmissions.Language>
    <#assign localizedPhrase = (iuclid.localizedPhraseDefinitionFor(firstLanguage.code, locale)) />
    <#if localizedPhrase.description?has_content>
        <#global languageLocale>${localizedPhrase.description}</#global>
    <#else>
        <#assign languageLocale><#assign locale = "en"></#assign>
    </#if>
<#else>
    <#assign languageLocale><#assign locale = "en"></#assign>
</#if>

<#import "translations_spc.ftl" as translations>
<#include "translations_spc.ftl">
<@translations.translateSPC/>

<#assign sysDateTime = .now>
<book version="5.0" xmlns="http://docbook.org/ns/docbook" xmlns:xi="http://www.w3.org/2001/XInclude">

    <#assign hist = ""/>
    <#global historyList = (getFirstHistoryOnly(_subject))!"" />
    <#global hist><#if historyList?has_content>${historyList.date}<#else> </#if></#global>
    <#global last_upd><#if header?has_content && historyList?has_content>${header}<#else> </#if></#global>

    <#assign left_header_text = ''/>
    <#assign central_header_text = "" />
    <#assign right_header_text = ''/>

    <#assign left_footer_text = sysDateTime?string["dd/MM/yyyy"] + " - IUCLID 6 " + iuclid6Version!/>
    <#assign central_footer_text =''/>
    <#assign right_footer_text =''/>

    <info>
        <@com.localizeXsl languageLocale />
        <@com.tocDepth 2 />

        <title>
            <para><para text-align="center" role="medium">${languageLocale?upper_case}</para></para>
            <para><para text-align="center" role="medium"><emphasis>${cover_page_annex?upper_case}
            </emphasis></para></para>
            <@com.emptyLine/>
            <para><para text-align="center" role="medium">${info_title_family?upper_case}</para></para>
        </title>

        <cover>
            <para role="align-center">
                <para role="medium">

                    <@spcUtils.frontPageCompositionNames mainMixtureCompositionSummaryList "family" />

                    <@com.emptyLine />
                    <emphasis role="bold">${cover_page_product_types}</emphasis>
                    <para><@spcUtils.productTypes usesList "usesListId" "en"/></para>

                    <#-- macro to populate dossier header related information -->
                    <@spcUtils.macroForPopulatingDossierHeader dossier />

                    <#if dossier?has_content>
                        <@com.emptyLine />
                        <para>
                            <emphasis
                                    role="bold"><@spcUtils.staticText "cover_page_auth_number" /></emphasis> <@com.text authNumber />
                        </para>
                    </#if>

                    <#if dossier?has_content>
                        <@com.emptyLine />
                        <para>
                            <emphasis role="bold">${cover_page_asset_number}</emphasis>
                            <#if _dossierHeader.SpecificSubmissions.AuthorisationDetails.ReferenceNumber?has_content>
                                <@com.text _dossierHeader.SpecificSubmissions.AuthorisationDetails.ReferenceNumber />
                            <#elseif !(_dossierHeader.SpecificSubmissions.AuthorisationDetails.ReferenceNumber?has_content)>
                                <@com.text externalAuthorisationNumber />
                            </#if>    
                        </para>
                    </#if>

                </para>
            </para>

        </cover>
        <@com.metadataBlock left_header_text central_header_text right_header_text left_footer_text central_footer_text right_footer_text />
    </info>

    <#------------------------------------>
    <#-- START OF CHAPTERS AND SECTIONS -->
    <#------------------------------------>
    <part>
        <title>
            <?linebreak?>
            <msgtext font-weight="normal">${part_1_title_family_chapter_1_single}</msgtext>
        </title>
        <chapter label="1">
            <!-- 1. ADMINISTRATIVE INFORMATION -->
            <title role="HEAD-1">${chapter_1_family_chapter_1_single}</title>

            <!-- 1.1 Family name of the product -->
            <section><title role="HEAD-2"><@spcUtils.addWhiteSpaces 2/>${section_1_1_family}</title>
                <#if _subject.MixtureName?has_content>
                    <@spcUtils.verticalHeaderTable "placeholder" "isMoreThanOneDoc" _subject "repeatableBlock" "${part_1_table1_3_cell2_family_table1_2_cell2_single}" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "twoColTable" "${tableID.table_id_1_family}"/>
                </#if>
            </section>

            <!-- 1.2 Product types -->
            <section><title role="HEAD-2"><@spcUtils.addWhiteSpaces 2/>${section_1_2_family}</title>
                <#if usesList?has_content>
                    <@spcUtils.verticalHeaderTable "placeholder" isMoreThanOneDoc(usesList) _subject "repeatableBlock" "${part_1_table1_2_cell1_part_2_table_1_3_cell1_family}" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "twoColTable" "${tableID.table_id_2_family}"/>
                </#if>
            </section>

            <!-- 1.3 Authorisation holder -->
            <section><title role="HEAD-1"><@spcUtils.addWhiteSpaces 2/>${section_1_3_family_section_1_2_single}</title>
                <#if dossier?has_content>
                    <#assign submittingLegalEntity = iuclid.getDocumentForKey(dossier.SpecificSubmissions.AuthorisationDetails.AuthorisationHolder) />
                    <@spcUtils.macroForPopulatingLegalEntity submittingLegalEntity "${tableID.table_id_3}" />
                    <@spcUtils.verticalHeaderTable "placeholder" "isMoreThanOneDoc" _subject "repeatableBlock" "${part_1_table1_3_cell1_family_table1_2_cell1_single}" "${part_1_table1_3_cell2_family_table1_2_cell2_single}" "${part_1_table1_3_cell3_family_table1_2_cell3_single}" "${part_1_table1_3_cell4_family_table1_2_cell4_single}" "${part_1_table1_3_cell5_family_table1_2_cell5_single}" "${part_1_table1_3_cell6_family_table1_2_cell6_single}" "${part_1_table1_3_cell7_family_table1_2_cell7_single}" "headerPlaceholder" "threeColTable" "${tableID.table_id_3}"/>
                </#if>
            </section>

            <!-- 1.4 Manufacturer(s) of the product -->
            <section><title role="HEAD-1"><@spcUtils.addWhiteSpaces 2/>${section_1_4_family_section_1_3_single}</title>
                <@spcUtils.manufacturerOfTheProduct/>
            </section>

            <!-- 1.5 Manufacturer(s) of the active substance(s) -->
            <section><title role="HEAD-1"><@spcUtils.addWhiteSpaces 2/>${section_1_5_family_section_1_4_single}</title>
                <@spcUtils.manufacturerOfTheActiveSubstanceSection "notMeta" "compositionSummary"/>
            </section>

        </chapter>

        <chapter label="2">
            <!-- 2. PRODUCT FAMILY COMPOSITION AND FORMULATION -->
            <title>${chapter_2_family}</title>
            <#assign repeatableBlock = getSummaryFamilyComposition(mainMixtureCompositionSummaryList "family") />
            <#if repeatableBlock?has_content>
                <!-- 2.1 Qualitative and quantitative information on the composition of the family -->
                <section><title role="HEAD-1"><@spcUtils.addWhiteSpaces 2/>${section_2_1_family}</title>
                    <@horizontalHeaderTable repeatableBlock isMoreThanOneDoc(mainMixtureCompositionList) _subject repeatableBlock "${part_1_part_2_table2_1_table7_cell1_family_table2_1_cell1_single}" "${part_1_part_2_table2_1_table7_cell2_family_table2_1_cell2_single}" "${part_1_part_2_table2_1_table7_cell3_family_table2_1_cell3_single}" "${part_1_part_2_table2_1_table7_cell4_family_table2_1_cell4_single}" "${part_1_part_2_table2_1_table7_cell5_family_table2_1_cell5_single}" "${part_1_part_2_table2_1_table7_cell6_family_table2_1_cell6_single}" "sixColTable" "${tableID.table_id_3_family}"/>
                </section>
            </#if>

            <!-- 2.2 Type of formulation -->
            <section><title role="HEAD-1"><@spcUtils.addWhiteSpaces 2/>${section_2_2_family_section_2_2_single}</title>
                <@spcUtils.verticalHeaderTable "placeholder" "isMoreThanOneDoc" _subject repeatableBlock "${part_1_part_2_table2_2_cell1_family}" "${part_1_table1_3_cell2_family_table1_2_cell2_single}" "${part_1_table1_3_cell3_family_table1_2_cell3_single}" "${part_1_table1_3_cell4_family_table1_2_cell4_single}" "${part_1_table1_3_cell5_family_table1_2_cell5_single}" "${part_1_table1_3_cell6_family_table1_2_cell6_single}" "${part_1_table1_3_cell7_family_table1_2_cell7_single}" "headerPlaceholder" "twoColTable" "${tableID.table_id_4_family}"/>
            </section>
        </chapter>
    </part>

    <part>
        <title>
            <?linebreak?>
            <msgtext>${part_2_title_family}</msgtext>
        </title>

        <#assign summaryMetaSPCcompositions = getSummaryCompositions(mainMixtureCompositionSummaryList "metaspc")>
        <#if summaryMetaSPCcompositions?has_content>
            <#list summaryMetaSPCcompositions as metaSPCcompositions>
                <#if metaSPCcompositions?has_content>
                    <#assign metaSPCcounter = [] />
                    <#assign metaSPCcounter>${metaSPCcompositions?index + 1}</#assign>

                    <chapter label="1">
                        <!-- 1. META SPC ADMINISTRATIVE INFORMATION -->
                        <title role="HEAD-1">${part_2_chapter_1_1_family} ${metaSPCcounter} ${part_2_chapter_1_2_family}</title>

                        <!-- 1.1 Meta SPC identifier -->
                        <section><title
                                    role="HEAD-1"><@spcUtils.addWhiteSpaces 2/>${part_2_section_1_1_1_family} ${metaSPCcounter} ${part_2_section_1_1_2_family}</title>
                            <#assign table_1_1_cell>${part_2_table_1_1_cell1_family}</#assign>
                            <#if mainMixtureCompositionSummaryList?has_content>
                                <@spcUtils.verticalHeaderTable metaSPCcounter "isMoreThanOneDoc" _subject metaSPCcompositions "${table_1_1_cell}" "${part_1_table1_3_cell2_family_table1_2_cell2_single}" "${part_1_table1_3_cell3_family_table1_2_cell3_single}" "${part_1_table1_3_cell4_family_table1_2_cell4_single}" "${part_1_table1_3_cell5_family_table1_2_cell5_single}" "${part_1_table1_3_cell6_family_table1_2_cell6_single}" "${part_1_table1_3_cell7_family_table1_2_cell7_single}" "headerPlaceholder" "twoColTable" "${tableID.table_id_12_family}"/>
                            </#if>
                        </section>

                        <!-- 1.2 Suffix to the authorisation number -->
                        <section><title role="HEAD-1"><@spcUtils.addWhiteSpaces 2/>${part_2_section_1_2_family}</title>
                            <#assign table_1_2_cell>${part_2_table_1_2_cell1_family}</#assign>
                            <@spcUtils.verticalHeaderTable metaSPCcounter "isMoreThanOneDoc" _subject metaSPCcompositions "${table_1_2_cell}" "${part_1_table1_3_cell2_family_table1_2_cell2_single}" "${part_1_table1_3_cell3_family_table1_2_cell3_single}" "${part_1_table1_3_cell4_family_table1_2_cell4_single}" "${part_1_table1_3_cell5_family_table1_2_cell5_single}" "${part_1_table1_3_cell6_family_table1_2_cell6_single}" "${part_1_table1_3_cell7_family_table1_2_cell7_single}" "headerPlaceholder" "twoColTable" "${tableID.table_id_13_family}"/>
                        </section>

                        <!-- 1.3 Product type(s) -->
                        <section><title role="HEAD-1"><@spcUtils.addWhiteSpaces 2/>${part_2_section_1_3_family}</title>
                            <#assign table_1_3_cell>${part_1_table1_2_cell1_part_2_table_1_3_cell1_family}</#assign>
                            <@spcUtils.verticalHeaderTable metaSPCcounter "isMoreThanOneDoc" _subject metaSPCcompositions "${table_1_3_cell}" "${part_1_table1_3_cell2_family_table1_2_cell2_single}" "${part_1_table1_3_cell3_family_table1_2_cell3_single}" "${part_1_table1_3_cell4_family_table1_2_cell4_single}" "${part_1_table1_3_cell5_family_table1_2_cell5_single}" "${part_1_table1_3_cell6_family_table1_2_cell6_single}" "${part_1_table1_3_cell7_family_table1_2_cell7_single}" "headerPlaceholder" "twoColTable" "${tableID.table_id_14_family}"/>
                        </section>
                    </chapter>

                    <chapter label="2">
                        <!-- 2. META SPC COMPOSITION -->
                        <title role="HEAD-1">
                        <#-- workaround for unique EN text, all other languages are correct -->
                        <#if languageLocale=="en">
                        ${part_2_section_1_1_1_family?upper_case} ${metaSPCcounter} COMPOSITION
                        <#elseif languageLocale!="en">
                        ${part_2_section_2_family?upper_case} ${metaSPCcounter}
                        </#if>
                        </title>

                        <!-- Qualitative and quantitative information on the composition of the meta SPC -->
                        <#assign repeatableBlock = getSummaryFamilyComposition(mainMixtureCompositionSummaryList "metaspc") />
                        <#if repeatableBlock?has_content>
                            <section><title
                                        role="HEAD-1"><@spcUtils.addWhiteSpaces 2/>${part_2_section_2_1_family} ${metaSPCcounter}</title>
                                <@horizontalHeaderTable metaSPCcompositions.ProductSummaryComposition.Composition isMoreThanOneDoc(mainMixtureCompositionList) _subject repeatableBlock "${part_1_part_2_table2_1_table7_cell1_family_table2_1_cell1_single}" "${part_1_part_2_table2_1_table7_cell2_family_table2_1_cell2_single}" "${part_1_part_2_table2_1_table7_cell3_family_table2_1_cell3_single}" "${part_1_part_2_table2_1_table7_cell4_family_table2_1_cell4_single}" "${part_1_part_2_table2_1_table7_cell5_family_table2_1_cell5_single}" "${part_1_part_2_table2_1_table7_cell6_family_table2_1_cell6_single}" "sixColTable" "${tableID.table_id_5_family}"/>
                            </section>
                        </#if>

                        <!-- Type(s) of formulation of the meta SPC -->
                        <section><title
                                    role="HEAD-1"><@spcUtils.addWhiteSpaces 2/>${part_2_section_2_2_family} ${metaSPCcounter}</title>
                            <#assign part2Table2Cell1>${part_1_part_2_table2_2_cell1_family}</#assign>
                            <@spcUtils.verticalHeaderTable metaSPCcompositions "isMoreThanOneDoc" _subject repeatableBlock "${part2Table2Cell1}" "${part_1_table1_3_cell2_family_table1_2_cell2_single}" "${part_1_table1_3_cell3_family_table1_2_cell3_single}" "${part_1_table1_3_cell4_family_table1_2_cell4_single}" "${part_1_table1_3_cell5_family_table1_2_cell5_single}" "${part_1_table1_3_cell6_family_table1_2_cell6_single}" "${part_1_table1_3_cell7_family_table1_2_cell7_single}" "headerPlaceholder" "twoColTable" "${tableID.table_id_6_family}"/>
                        </section>
                    </chapter>

                    <chapter label="3">
                        <!-- 3. HAZARD AND PRECAUTIONARY STATEMENTS OF THE META SPC -->
                        <title role="HEAD-1">${part_2_chapter_3_family} ${metaSPCcounter}</title>
                        <#assign ghsMetaSPC = iuclid.getDocumentForKey(metaSPCcompositions.MetaSPC.ClassificationAndLabelling)/>
                        <#if ghsMetaSPC?has_content>
                        <#-- headers -->
                            <#assign part_2_table_3_cell1_family_table3_cell1_single>${part_2_table_3_cell1_family_table3_cell1_single}</#assign>
                            <#assign part_2_table_3_cell2_family_table3_cell2_single>${part_2_table_3_cell2_family_table3_cell2_single}</#assign>
                            <@spcUtils.macroForPopulatingGhsLabelling metaSPCcompositions "${tableID.table_id_7_family}"/>
                            <@spcUtils.verticalHeaderTable metaSPCcompositions "isMoreThanOneDoc" _subject "repeatableBlock" "${part_2_table_3_cell1_family_table3_cell1_single}" "${part_2_table_3_cell2_family_table3_cell2_single}" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "twoColTable" "${tableID.table_id_7_family}"/>
                        </#if>
                    </chapter>

                    <chapter label="4">
                        <!-- 4. AUTHORISED USE(S) OF THE META SPC -->
                        <title role="HEAD-1">${part_2_chapter_4_family}</title>
                        <#assign useMetaSPC = [] />
                        <#list metaSPCcompositions.MetaSPC.AuthorisedUses as usesMetaSPC>
                            <#assign useMetaSPC = iuclid.getDocumentForKey(usesMetaSPC)/>
                            <#if useMetaSPC?has_content>
                                <#assign indexcounter>${usesMetaSPC?index + 1}</#assign>
                                <section>
                                    <title role="HEAD-4"><@spcUtils.addWhiteSpaces 2/>${part_2_section_4_1_family_section_4_1_table_single_use_description}</title>
                                    <@spcUtils.macroForUseData useMetaSPC "${languageLocale}" />
                                    <#-- headers-->
                                    <@spcUtils.useDescription "isMoreThanOneDoc" useMetaSPC indexcounter "${part_2_table4_1_cell1_family_table4_1_cell1_single}" "${part_2_table4_1_cell2_family_table4_1_cell2_single}" "${part_2_table4_1_cell3_family_table4_1_cell3_single}" "${part_2_table4_1_cell4_family_table4_1_cell4_single}" "${part_2_table4_1_cell5_family_table4_1_cell5_single}" "${part_2_table4_1_cell6_family_table4_1_cell6_single}" "${part_2_table4_1_cell7_family_table4_1_cell7_single}" "${part_2_table4_1_cell8_family_table4_1_cell8_single}"/>
                                    <@spcUtils.directionsForUseReferencedByAuthorisedUses useMetaSPC "${tableID.table_id_8_family}"/>
                                </section>
                            </#if>
                        </#list>
                    </chapter>

                    <chapter label="5">
                        <!-- 5. GENERAL DIRECTIONS FOR USE OF THE META SPC -->
                        <title role="HEAD-1">${part_2_chapter_5_family} ${metaSPCcounter}</title>
                        <#-- macro to only get protection measures *protectionMeasuresList* not linked to authorised uses -->
                        <#assign generalDirectionsForUseMetaSPC = iuclid.getDocumentForKey(metaSPCcompositions.MetaSPC.InstructionsForUseAndMeasuresToProtect)/>
                        <@spcUtils.directionsForUseForMetaSPC generalDirectionsForUseMetaSPC "${tableID.table_id_8_family}" />
                    </chapter>

                    <chapter label="6">
                        <!-- 6. OTHER INFORMATION -->
                        <title role="HEAD-1">${part_2_chapter_6_family_part_2_chapter_6_single}</title>
                        <#assign otherInformationForUseMetaSPC = iuclid.getDocumentForKey(metaSPCcompositions.MetaSPC.SummaryAndEvaluation)/>
                        <@spcUtils.otherInformation otherInformationForUseMetaSPC "${tableID.table_id_9_family}" />
                    </chapter>

                    <!-- 7. THIRD INFORMATION LEVEL: INDIVIDUAL PRODUCTS IN THE META SPC -->
                    <chapter label="7">
                        <title role="HEAD-1">${part_2_chapter_7_family} ${metaSPCcounter}</title>
                        <!-- List through products in meta spc -->
                        <#if metaSPCcompositions.ProductCompositions.ProductCompositions?has_content>
                            <#list metaSPCcompositions.ProductCompositions.ProductCompositions as productCompositions>
                                <#if productCompositions?has_content>
                                    <!-- get key for those products -->
                                    <#assign productComposition = iuclid.getDocumentForKey(productCompositions)/>
                                    <#if productComposition?has_content>
                                        <#assign productArray = [] />
                                        <#assign productArray = productArray + [productComposition] />
                                        <!-- get components of the products ready for output in table -->
                                        <#assign repeatableBlock = spcUtils.getComponents(productComposition, "${tableID.table_id_10_family}")/>
                                        <#if repeatableBlock?has_content>
                                            <section><title
                                                        role="HEAD-1"><@spcUtils.addWhiteSpaces 2/>${part_2_section_7_1_family}</title>
                                                <#if productArray?has_content>
                                                    <@spcUtils.verticalHeaderTable productArray "isMoreThanOneDoc" _subject metaSPCcompositions "${part_2_table7_cell1_family_table1_1_cell1_single}" "${part_1_table1_3_cell4_family_table1_2_cell4_single}" "${part_2_table7_cell3_family}" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "headerPlaceholder" "threeColTable" "${tableID.table_id_11_family}"/>
                                                </#if>

                                                <#if productArray?has_content>
                                                    <@spcUtils.horizontalHeaderTable repeatableBlock isMoreThanOneDoc(mainMixtureCompositionList) _subject repeatableBlock "${part_1_part_2_table2_1_table7_cell1_family_table2_1_cell1_single}" "${part_1_part_2_table2_1_table7_cell2_family_table2_1_cell2_single}" "${part_1_part_2_table2_1_table7_cell3_family_table2_1_cell3_single}" "${part_1_part_2_table2_1_table7_cell4_family_table2_1_cell4_single}" "${part_1_part_2_table2_1_table7_cell5_family_table2_1_cell5_single}" "${part_1_part_2_table2_1_table7_cell6_family_table2_1_cell6_single}" "sixColTable" "${tableID.table_id_10_family}"/>
                                                </#if>
                                            </section>
                                        </#if>
                                    </#if>
                                </#if>
                            </#list>
                        </#if>
                    </chapter>

                </#if>
            </#list>
        </#if>
    </part>

    <#function getFirstHistoryOnly _subject>
        <#attempt>
            <#local historyList = iuclid.getHistoryForDocumentKey(_subject.documentKey) />


            <#if !(historyList)?has_content>
                <#return [] />
            </#if>

            <#if historyList?has_content>
                <#list historyList as history>
                    <#if !(history)?has_content>
                        <#return [] />
                    <#else/>
                        <#return historyList[0] />
                    </#if>
                </#list>
            </#if>

            <#recover>

                <#return [] />
        </#attempt>
        <#return [] />
    </#function>
</book>
